@@ -47,8 +47,6 @@
 #include <glib/gstdio.h>
 #include <gmodule.h>
 
-#include <gconf/gconf-client.h>
-
 #include "brasero-units.h"
 
 #include "burn-job.h"
@@ -88,8 +86,9 @@ typedef struct _BraseroWodimPrivate BraseroWodimPrivate;
 
 static GObjectClass *parent_class = NULL;
 
-#define GCONF_KEY_IMMEDIATE_FLAG	"/apps/brasero/config/immed_flag"
-#define GCONF_KEY_MINBUF_VALUE		"/apps/brasero/config/minbuf_value"
+#define BRASERO_SCHEMA_CONFIG		"org.gnome.brasero.config"
+#define BRASERO_KEY_IMMEDIATE_FLAG      "immed-flag"
+#define BRASERO_KEY_MINBUF_VALUE	"minbuf-value"
 
 static BraseroBurnResult
 brasero_wodim_stderr_read (BraseroProcess *process, const gchar *line)
@@ -271,6 +270,33 @@ brasero_wodim_compute (BraseroWodim *wodim,
 	}
 }
 
+static void
+brasero_wodim_set_rate (BraseroProcess *process,
+                        int speed_1,
+                        int speed_2)
+{
+	gdouble current_rate;
+	BraseroMedia media;
+
+	if (brasero_job_get_media (BRASERO_JOB (process), &media) != BRASERO_BURN_OK)
+		return;
+
+	if (BRASERO_MEDIUM_IS (media, BRASERO_MEDIUM_CD))
+		current_rate = (gdouble) ((gdouble) speed_1 +
+			       (gdouble) speed_2 / 10.0) *
+			       (gdouble) CD_RATE;
+	else if (BRASERO_MEDIUM_IS (media, BRASERO_MEDIUM_DVD))
+		current_rate = (gdouble) ((gdouble) speed_1 +
+			       (gdouble) speed_2 / 10.0) *
+			       (gdouble) DVD_RATE;
+	else if (BRASERO_MEDIUM_IS (media, BRASERO_MEDIUM_BD))
+		current_rate = (gdouble) ((gdouble) speed_1 +
+			       (gdouble) speed_2 / 10.0) *
+			       (gdouble) BD_RATE;
+
+	brasero_job_set_rate (BRASERO_JOB (process), current_rate);
+}
+
 static BraseroBurnResult
 brasero_wodim_stdout_read (BraseroProcess *process, const gchar *line)
 {
@@ -284,14 +310,11 @@ brasero_wodim_stdout_read (BraseroProcess *process, const gchar *line)
 	priv = BRASERO_WODIM_PRIVATE (wodim);
 
 	if (sscanf (line, "Track %2u: %d of %d MB written (fifo %d%%) [buf %d%%] %d.%dx.",
-		    &track, &mb_written, &mb_total, &fifo, &buf, &speed_1, &speed_2) == 7) {
-		gdouble current_rate;
-
-		current_rate = (gdouble) ((gdouble) speed_1 +
-			       (gdouble) speed_2 / 10.0) *
-			       (gdouble) CD_RATE;
-		brasero_job_set_rate (BRASERO_JOB (wodim), current_rate);
-
+		    &track, &mb_written, &mb_total, &fifo, &buf, &speed_1, &speed_2) == 7 ||
+	    /* This is for DVD+R */
+	    sscanf (line, "Track %2u:    %d of %d MB written (fifo  %d%%) [buf  %d%%] |%*s  %*s|   %d.%dx.",
+	            &track, &mb_written, &mb_total, &fifo, &buf, &speed_1, &speed_2) == 7) {
+		brasero_wodim_set_rate (process, speed_1, speed_2);
 		priv->current_track_written = (goffset) mb_written * (goffset) 1048576LL;
 		brasero_wodim_compute (wodim,
 				       mb_written,
@@ -301,15 +324,11 @@ brasero_wodim_stdout_read (BraseroProcess *process, const gchar *line)
 		brasero_job_start_progress (BRASERO_JOB (wodim), FALSE);
 	} 
 	else if (sscanf (line, "Track %2u:    %d MB written (fifo %d%%) [buf  %d%%]  %d.%dx.",
+			 &track, &mb_written, &fifo, &buf, &speed_1, &speed_2) == 6 ||
+	         sscanf (line, "Track %2u:    %d MB written (fifo %d%%) [buf  %d%%] |%*s  %*s|   %d.%dx.",
 			 &track, &mb_written, &fifo, &buf, &speed_1, &speed_2) == 6) {
-		gdouble current_rate;
-
 		/* this line is printed when wodim writes on the fly */
-		current_rate = (gdouble) ((gdouble) speed_1 +
-			       (gdouble) speed_2 / 10.0) *
-			       (gdouble) CD_RATE;
-		brasero_job_set_rate (BRASERO_JOB (wodim), current_rate);
-
+		brasero_wodim_set_rate (process, speed_1, speed_2);
 		priv->current_track_written = (goffset) mb_written * (goffset) 1048576LL;
 		if (brasero_job_get_fd_in (BRASERO_JOB (wodim), NULL) == BRASERO_BURN_OK) {
 			goffset bytes = 0;
@@ -1180,23 +1199,20 @@ brasero_wodim_class_init (BraseroWodimClass *klass)
 static void
 brasero_wodim_init (BraseroWodim *obj)
 {
-	GConfClient *client;
+	GSettings *settings;
 	BraseroWodimPrivate *priv;
 
 	/* load our "configuration" */
 	priv = BRASERO_WODIM_PRIVATE (obj);
 
-	client = gconf_client_get_default ();
-	priv->immediate = gconf_client_get_bool (client,
-						 GCONF_KEY_IMMEDIATE_FLAG,
-						 NULL);
-	priv->minbuf = gconf_client_get_int (client,
-					     GCONF_KEY_MINBUF_VALUE,
-					     NULL);
+	settings = g_settings_new (BRASERO_SCHEMA_CONFIG);
+
+	priv->immediate = g_settings_get_boolean (settings, BRASERO_KEY_IMMEDIATE_FLAG);
+	priv->minbuf = g_settings_get_int (settings, BRASERO_KEY_MINBUF_VALUE);
 	if (priv->minbuf > 95 || priv->minbuf < 25)
 		priv->minbuf = 30;
 
-	g_object_unref (client);
+	g_object_unref (settings);
 }
 
 static void
@@ -1255,6 +1271,7 @@ brasero_wodim_export_caps (BraseroPlugin *plugin)
 	/* NOTE: it seems that cdrecord can burn cue files on the fly */
 	brasero_plugin_define (plugin,
 			       "wodim",
+	                       NULL,
 			       _("Burns, blanks and formats CDs and DVDs"),
 			       "Philippe Rouquier",
 			       0);
@@ -1398,10 +1415,10 @@ brasero_wodim_export_caps (BraseroPlugin *plugin)
 					BRASERO_BURN_FLAG_NONE);
 
 	/* add some configure options */
-	immed = brasero_plugin_conf_option_new (GCONF_KEY_IMMEDIATE_FLAG,
+	immed = brasero_plugin_conf_option_new (BRASERO_KEY_IMMEDIATE_FLAG,
 						_("Enable the \"-immed\" flag (see wodim manual)"),
 						BRASERO_PLUGIN_OPTION_BOOL);
-	minbuf = brasero_plugin_conf_option_new (GCONF_KEY_MINBUF_VALUE,
+	minbuf = brasero_plugin_conf_option_new (BRASERO_KEY_MINBUF_VALUE,
 						 _("Minimum drive buffer fill ratio (in %) (see wodim manual):"),
 						 BRASERO_PLUGIN_OPTION_INT);
 	brasero_plugin_conf_option_int_set_range (minbuf, 25, 95);
