@@ -394,11 +394,12 @@ brasero_transcode_create_pipeline (BraseroTranscode *transcode,
 				   GError **error)
 {
 	gchar *uri;
-	GValue *value = NULL;
+	gboolean keep_dts;
 	GstElement *decode;
 	GstElement *source;
 	GstBus *bus = NULL;
 	GstCaps *filtercaps;
+	GValue *value = NULL;
 	GstElement *pipeline;
 	GstElement *sink = NULL;
 	BraseroJobAction action;
@@ -408,7 +409,6 @@ brasero_transcode_create_pipeline (BraseroTranscode *transcode,
 	BraseroTrack *track = NULL;
 	GstElement *resample = NULL;
 	BraseroTranscodePrivate *priv;
-	BraseroStreamFormat session_format;
 
 	priv = BRASERO_TRANSCODE_PRIVATE (transcode);
 
@@ -484,6 +484,7 @@ brasero_transcode_create_pipeline (BraseroTranscode *transcode,
 			g_object_set (sink,
 				      "location", output,
 				      NULL);
+			g_free (output);
 		}
 		else {
 			int fd;
@@ -514,13 +515,16 @@ brasero_transcode_create_pipeline (BraseroTranscode *transcode,
 		      "sync", FALSE,
 		      NULL);
 
-	session_format = BRASERO_AUDIO_FORMAT_RAW;
-	brasero_job_tag_lookup (BRASERO_JOB (transcode), BRASERO_SESSION_STREAM_AUDIO_FORMAT, &value);
+	brasero_job_tag_lookup (BRASERO_JOB (transcode),
+				BRASERO_SESSION_STREAM_AUDIO_FORMAT,
+				&value);
 	if (value)
-		session_format = g_value_get_int (value);
-	
-	if (action == BRASERO_JOB_ACTION_IMAGE
-	&& (session_format & BRASERO_AUDIO_FORMAT_DTS) != 0
+		keep_dts = (g_value_get_int (value) & BRASERO_AUDIO_FORMAT_DTS) != 0;
+	else
+		keep_dts = FALSE;
+
+	if (keep_dts
+	&&  action == BRASERO_JOB_ACTION_IMAGE
 	&& (brasero_track_stream_get_format (BRASERO_TRACK_STREAM (track)) & BRASERO_AUDIO_FORMAT_DTS) != 0) {
 		GstElement *wavparse;
 		GstPad *sinkpad;
@@ -541,13 +545,6 @@ brasero_transcode_create_pipeline (BraseroTranscode *transcode,
 		}
 		gst_bin_add (GST_BIN (pipeline), wavparse);
 
-		priv->link = NULL;
-		priv->sink = sink;
-		priv->decode = NULL;
-		priv->source = source;
-		priv->convert = NULL;
-		priv->pipeline = pipeline;
-
 		if (!gst_element_link (source, wavparse)) {
 			g_set_error (error,
 				     BRASERO_BURN_ERROR,
@@ -565,13 +562,21 @@ brasero_transcode_create_pipeline (BraseroTranscode *transcode,
 		 * gstreamer. Yet this is unfortunately a necessary evil. */
 		priv->pos = 0;
 		priv->size = 0;
-		sinkpad = gst_element_get_pad (priv->sink, "sink");
+		sinkpad = gst_element_get_pad (sink, "sink");
 		priv->probe = gst_pad_add_buffer_probe (sinkpad,
 							G_CALLBACK (brasero_transcode_buffer_handler),
 							transcode);
 		gst_object_unref (sinkpad);
 
-		gst_element_set_state (priv->pipeline, GST_STATE_PLAYING);
+
+		priv->link = NULL;
+		priv->sink = sink;
+		priv->decode = NULL;
+		priv->source = source;
+		priv->convert = NULL;
+		priv->pipeline = pipeline;
+
+		gst_element_set_state (pipeline, GST_STATE_PLAYING);
 		return TRUE;
 	}
 
@@ -588,6 +593,14 @@ brasero_transcode_create_pipeline (BraseroTranscode *transcode,
 	gst_bin_add (GST_BIN (pipeline), convert);
 
 	if (action == BRASERO_JOB_ACTION_IMAGE) {
+		BraseroStreamFormat session_format;
+		BraseroTrackType *output_type;
+
+		output_type = brasero_track_type_new ();
+		brasero_job_get_output_type (BRASERO_JOB (transcode), output_type);
+		session_format = brasero_track_type_get_stream_format (output_type);
+		brasero_track_type_free (output_type);
+
 		/* audioresample */
 		resample = gst_element_factory_make ("audioresample", NULL);
 		if (resample == NULL) {
@@ -615,7 +628,8 @@ brasero_transcode_create_pipeline (BraseroTranscode *transcode,
 								   "channels", G_TYPE_INT, 2,
 								   "width", G_TYPE_INT, 16,
 								   "depth", G_TYPE_INT, 16,
-								   "endianness", G_TYPE_INT, 1234,
+								   /* NOTE: we use little endianness only for libburn which requires little */
+								   "endianness", G_TYPE_INT, (session_format & BRASERO_AUDIO_FORMAT_RAW_LITTLE_ENDIAN) != 0 ? 1234:4321,
 								   "rate", G_TYPE_INT, 44100,
 								   "signed", G_TYPE_BOOLEAN, TRUE,
 								   NULL),
@@ -636,17 +650,12 @@ brasero_transcode_create_pipeline (BraseroTranscode *transcode,
 	}
 	gst_bin_add (GST_BIN (pipeline), decode);
 
-	priv->sink = sink;
-	priv->decode = decode;
-	priv->source = source;
-	priv->convert = convert;
-	priv->pipeline = pipeline;
-
 	if (action == BRASERO_JOB_ACTION_IMAGE) {
 		GstPad *sinkpad;
 		gboolean res;
 
-		if (!gst_element_link_many (source, decode, NULL)) {
+		if (!gst_element_link (source, decode)) {
+			BRASERO_JOB_LOG (transcode, "Impossible to link plugin pads");
 			g_set_error (error,
 				     BRASERO_BURN_ERROR,
 				     BRASERO_BURN_ERROR_GENERAL,
@@ -663,12 +672,11 @@ brasero_transcode_create_pipeline (BraseroTranscode *transcode,
 		if (volume) {
 			gst_bin_add (GST_BIN (pipeline), volume);
 			res = gst_element_link_many (resample,
-			                             convert,
 			                             volume,
+						     convert,
 			                             filter,
 			                             sink,
 			                             NULL);
-
 		}
 		else
 			res = gst_element_link_many (resample,
@@ -678,6 +686,7 @@ brasero_transcode_create_pipeline (BraseroTranscode *transcode,
 			                             NULL);
 
 		if (!res) {
+			BRASERO_JOB_LOG (transcode, "Impossible to link plugin pads");
 			g_set_error (error,
 				     BRASERO_BURN_ERROR,
 				     BRASERO_BURN_ERROR_GENERAL,
@@ -689,7 +698,7 @@ brasero_transcode_create_pipeline (BraseroTranscode *transcode,
 		 * gstreamer. Yet this is unfortunately a necessary evil. */
 		priv->pos = 0;
 		priv->size = 0;
-		sinkpad = gst_element_get_pad (priv->sink, "sink");
+		sinkpad = gst_element_get_pad (sink, "sink");
 		priv->probe = gst_pad_add_buffer_probe (sinkpad,
 							G_CALLBACK (brasero_transcode_buffer_handler),
 							transcode);
@@ -698,6 +707,7 @@ brasero_transcode_create_pipeline (BraseroTranscode *transcode,
 	else {
 		if (!gst_element_link (source, decode)
 		||  !gst_element_link (convert, sink)) {
+			BRASERO_JOB_LOG (transcode, "Impossible to link plugin pads");
 			g_set_error (error,
 				     BRASERO_BURN_ERROR,
 				     BRASERO_BURN_ERROR_GENERAL,
@@ -712,7 +722,13 @@ brasero_transcode_create_pipeline (BraseroTranscode *transcode,
 				  transcode);
 	}
 
-	gst_element_set_state (priv->pipeline, GST_STATE_PLAYING);
+	priv->sink = sink;
+	priv->decode = decode;
+	priv->source = source;
+	priv->convert = convert;
+	priv->pipeline = pipeline;
+
+	gst_element_set_state (pipeline, GST_STATE_PLAYING);
 	return TRUE;
 
 error:
@@ -1090,6 +1106,7 @@ brasero_transcode_push_track (BraseroTranscode *transcode)
 
 	track = brasero_track_stream_new ();
 	brasero_track_stream_set_source (track, output);
+	g_free (output);
 
 	/* FIXME: what if input had metadata ?*/
 	brasero_track_stream_set_format (track, BRASERO_AUDIO_FORMAT_RAW);
@@ -1097,7 +1114,7 @@ brasero_transcode_push_track (BraseroTranscode *transcode)
 	brasero_track_tag_copy_missing (BRASERO_TRACK (track), src);
 
 	brasero_job_add_track (BRASERO_JOB (transcode), BRASERO_TRACK (track));
-
+	
 	/* It's good practice to unref the track afterwards as we don't need it
 	 * anymore. BraseroTaskCtx refs it. */
 	g_object_unref (track);
@@ -1420,7 +1437,7 @@ foreach_tag (const GstTagList *list,
 
 			gst_tag_list_get_string (list, tag, &isrc);
 			brasero_track_tag_add_int (track,
-						   BRASERO_TRACK_STREAM_ARTIST_TAG,
+						   BRASERO_TRACK_STREAM_ISRC_TAG,
 						   (int) g_ascii_strtoull (isrc, NULL, 10));
 		}
 	}
@@ -1533,6 +1550,7 @@ brasero_transcode_active_state (BraseroTranscode *transcode)
 					 "start decoding %s to %s",
 					 uri,
 					 dest);
+			g_free (dest);
 		}
 		else
 			BRASERO_JOB_LOG (transcode,
@@ -1742,21 +1760,23 @@ brasero_transcode_finalize (GObject *object)
 	G_OBJECT_CLASS (parent_class)->finalize (object);
 }
 
-static BraseroBurnResult
-brasero_transcode_export_caps (BraseroPlugin *plugin, gchar **error)
+static void
+brasero_transcode_export_caps (BraseroPlugin *plugin)
 {
 	GSList *input;
 	GSList *output;
 
 	brasero_plugin_define (plugin,
 			       "transcode",
-			       _("Transcode converts song files into a format proper to burn them on CDs"),
+	                       NULL,
+			       _("Converts any song file into a format suitable for audio CDs"),
 			       "Philippe Rouquier",
-			       0);
+			       1);
 
 	output = brasero_caps_audio_new (BRASERO_PLUGIN_IO_ACCEPT_FILE|
 					 BRASERO_PLUGIN_IO_ACCEPT_PIPE,
 					 BRASERO_AUDIO_FORMAT_RAW|
+					 BRASERO_AUDIO_FORMAT_RAW_LITTLE_ENDIAN|
 					 BRASERO_METADATA_INFO);
 
 	input = brasero_caps_audio_new (BRASERO_PLUGIN_IO_ACCEPT_FILE,
@@ -1775,7 +1795,8 @@ brasero_transcode_export_caps (BraseroPlugin *plugin, gchar **error)
 
 	output = brasero_caps_audio_new (BRASERO_PLUGIN_IO_ACCEPT_FILE|
 					 BRASERO_PLUGIN_IO_ACCEPT_PIPE,
-					 BRASERO_AUDIO_FORMAT_RAW);
+					 BRASERO_AUDIO_FORMAT_RAW|
+					 BRASERO_AUDIO_FORMAT_RAW_LITTLE_ENDIAN);
 
 	input = brasero_caps_audio_new (BRASERO_PLUGIN_IO_ACCEPT_FILE,
 					BRASERO_AUDIO_FORMAT_UNDEFINED);
@@ -1789,6 +1810,4 @@ brasero_transcode_export_caps (BraseroPlugin *plugin, gchar **error)
 	brasero_plugin_link_caps (plugin, output, input);
 	g_slist_free (output);
 	g_slist_free (input);
-
-	return BRASERO_BURN_OK;
 }
