@@ -89,6 +89,7 @@
 #include "brasero-notify.h"
 #include "brasero-project-parse.h"
 #include "brasero-project-name.h"
+#include "brasero-drive-settings.h"
 
 static void brasero_project_class_init (BraseroProjectClass *klass);
 static void brasero_project_init (BraseroProject *sp);
@@ -1163,6 +1164,7 @@ brasero_project_init (BraseroProject *obj)
 			    0);
 
 	g_object_unref (size_group);
+	
 }
 
 static void
@@ -1318,7 +1320,7 @@ brasero_project_install_missing (BraseroPluginErrorType type,
 
 	/* Get the xid */
 	parent = gtk_widget_get_toplevel (GTK_WIDGET (project));
-	xid = gdk_x11_drawable_get_xid (GDK_DRAWABLE (GTK_WIDGET (parent)->window));
+	xid = gdk_x11_drawable_get_xid (GDK_DRAWABLE (gtk_widget_get_window (parent)));
 
 	package = brasero_pk_new ();
 	cancel = g_cancellable_new ();
@@ -1616,11 +1618,12 @@ brasero_project_image_properties (BraseroProject *project)
 	return (answer == GTK_RESPONSE_OK) ? BRASERO_BURN_OK:BRASERO_BURN_ERR;
 }
 
-void
+static void
 brasero_project_burn (BraseroProject *project)
 {
 	BraseroBurnResult res;
 	BraseroDisc *current_disc;
+	BraseroDriveSettings *settings;
 
 	/* Check that we are ready */
 	if (brasero_project_check_status (project) != BRASERO_BURN_OK)
@@ -1630,13 +1633,20 @@ brasero_project_burn (BraseroProject *project)
 	if (brasero_project_check_plugins_not_ready (project, BRASERO_BURN_SESSION (project->priv->session)) != BRASERO_BURN_OK)
 		return;
 
+	/* Set saved parameters for the session */
+	settings = brasero_drive_settings_new ();
+	brasero_drive_settings_set_session (settings, BRASERO_BURN_SESSION (project->priv->session));
+
 	if (!brasero_burn_session_is_dest_file (BRASERO_BURN_SESSION (project->priv->session)))
 		res = brasero_project_drive_properties (project);
 	else
 		res = brasero_project_image_properties (project);
 
-	if (res != BRASERO_BURN_OK && res != BRASERO_BURN_RETRY)
+	if (res != BRASERO_BURN_OK
+	&&  res != BRASERO_BURN_RETRY) {
+		g_object_unref (settings);
 		return;
+	}
 
 	project->priv->is_burning = 1;
 
@@ -1656,6 +1666,8 @@ brasero_project_burn (BraseroProject *project)
 						 BRASERO_BURN_SESSION (project->priv->session),
 						 res == BRASERO_BURN_RETRY);
 
+	g_object_unref (settings);
+
 	/* empty the stack of temporary tracks */
 	while (brasero_burn_session_pop_tracks (BRASERO_BURN_SESSION (project->priv->session)) == BRASERO_BURN_RETRY);
 
@@ -2011,9 +2023,6 @@ void
 brasero_project_set_source (BraseroProject *project,
 			    BraseroURIContainer *source)
 {
-	if (project->priv->chooser)
-		gtk_dialog_response (GTK_DIALOG (project->priv->chooser), GTK_RESPONSE_CANCEL);
-
 	if (project->priv->activated_id) {
 		g_signal_handler_disconnect (project->priv->current_source,
 					     project->priv->activated_id);
@@ -2139,7 +2148,7 @@ brasero_project_update_preview (GtkFileChooser *chooser,
 {
 	gchar *uri;
 
-	gtk_file_chooser_set_preview_widget_active (chooser, FALSE);
+	gtk_file_chooser_set_preview_widget_active (chooser, TRUE);
 
 	uri = gtk_file_chooser_get_preview_uri (chooser);
 	brasero_player_set_uri (player, uri);
@@ -2246,7 +2255,7 @@ brasero_project_add_uris_cb (GtkAction *action,
 	player = brasero_player_new ();
 
 	gtk_widget_show (player);
-	gtk_file_chooser_set_preview_widget_active (GTK_FILE_CHOOSER (project->priv->chooser), FALSE);
+	gtk_file_chooser_set_preview_widget_active (GTK_FILE_CHOOSER (project->priv->chooser), TRUE);
 	gtk_file_chooser_set_use_preview_label (GTK_FILE_CHOOSER (project->priv->chooser), FALSE);
 	gtk_file_chooser_set_preview_widget (GTK_FILE_CHOOSER (project->priv->chooser), player);
 
